@@ -60,7 +60,6 @@ from micropython import const
 
 
 # Internal constants and register values:
-# pylint: disable=bad-whitespace
 _FXAS21002C_ADDRESS = const(0x21)  # 0100001
 _FXAS21002C_ID = const(0xD7)  # 1101 0111
 _GYRO_REGISTER_STATUS = const(0x00)
@@ -84,7 +83,9 @@ GYRO_RANGE_250DPS = 250
 GYRO_RANGE_500DPS = 500
 GYRO_RANGE_1000DPS = 1000
 GYRO_RANGE_2000DPS = 2000
-# pylint: enable=bad-whitespace
+
+# Unit conversion:
+DEGREE_TO_RAD = 3.141592653589793 / 180
 
 
 class FXAS21002C:
@@ -174,4 +175,5 @@ class FXAS21002C:
             factor = _GYRO_SENSITIVITY_1000DPS
         elif self._gyro_range == GYRO_RANGE_2000DPS:
             factor = _GYRO_SENSITIVITY_2000DPS
+        factor *= DEGREE_TO_RAD
         return [x * factor for x in raw]
